@@ -6,7 +6,7 @@ package BSON::Double;
 # ABSTRACT: BSON type wrapper for Double
 
 use version;
-our $VERSION = 'v0.999.1'; # TRIAL
+our $VERSION = 'v0.999.2'; # TRIAL
 
 use Carp;
 
@@ -25,6 +25,12 @@ has 'value' => (
 
 use namespace::clean -except => 'meta';
 
+use constant {
+    nInf  => unpack("d",pack("H*","000000000000f0ff")),
+    pInf  => unpack("d",pack("H*","000000000000f07f")),
+    NaN   => unpack("d",pack("H*","000000000000f8ff")),
+};
+
 sub BUILD {
     my $self = shift;
     # coerce to NV internally
@@ -46,7 +52,27 @@ sub TO_JSON {
 }
 
 use overload (
-    q{0+}    => sub { $_[0]->{value} },
+    # Unary
+    q{""} => sub { "$_[0]->{value}" },
+    q{0+} => sub { $_[0]->{value} },
+    q{~}  => sub { ~( $_[0]->{value} ) },
+    # Binary
+    ( map { $_ => eval "sub { return \$_[0]->{value} $_ \$_[1] }" } qw( + * ) ), ## no critic
+    (
+        map {
+            $_ => eval ## no critic
+              "sub { return \$_[2] ? \$_[1] $_ \$_[0]->{value} : \$_[0]->{value} $_ \$_[1] }"
+        } qw( - / % ** << >> x <=> cmp & | ^ )
+    ),
+    (
+        map { $_ => eval "sub { return $_(\$_[0]->{value}) }" } ## no critic
+          qw( cos sin exp log sqrt int )
+    ),
+    q{atan2} => sub {
+        return $_[2] ? atan2( $_[1], $_[0]->{value} ) : atan2( $_[0]->{value}, $_[1] );
+    },
+
+    # Special
     fallback => 1,
 );
 
@@ -62,7 +88,7 @@ BSON::Double - BSON type wrapper for Double
 
 =head1 VERSION
 
-version v0.999.1
+version v0.999.2
 
 =head1 SYNOPSIS
 
@@ -89,12 +115,36 @@ will be coerced to Perl's numeric type.  The default is 0.0.
 Returns a double, unless the value is 'Inf', '-Inf' or 'NaN'
 (which are illegal in JSON), in which case an exception is thrown.
 
-=for Pod::Coverage BUILD
+=for Pod::Coverage BUILD nInf pInf NaN
+
+=head1 INFINITY AND NAN
+
+Some Perls may not support converting "Inf" or "NaN" strings to their
+double equivalent.  They are available as functions from the L<POSIX>
+module, but as a lighter alternative to POSIX, the following functions are
+available:
+
+=over 4
+
+=item *
+
+BSON::Double::pInf() – positive infinity
+
+=item *
+
+BSON::Double::nInf() – negative infinity
+
+=item *
+
+BSON::Double::NaN() – not-a-number
+
+=back
 
 =head1 OVERLOADING
 
-The numification operator, C<0+> is overloaded to return the C<value>
-and fallback overloading is enabled.
+The numification operator, C<0+> is overloaded to return the C<value>,
+the full "minimal set" of overloaded operations is provided (per L<overload>
+documentation) and fallback overloading is enabled.
 
 =head1 AUTHORS
 
