@@ -6,7 +6,7 @@ package BSON::Int64;
 # ABSTRACT: BSON type wrapper for Int64
 
 use version;
-our $VERSION = 'v0.999.1'; # TRIAL
+our $VERSION = 'v0.999.2'; # TRIAL
 
 use Carp;
 use Config;
@@ -95,8 +95,27 @@ sub TO_JSON {
 }
 
 use overload (
-    q{""}    => sub { $_[0]->{value} },
-    q{0+}    => sub { $_[0]->{value} },
+    # Unary
+    q{""} => sub { "$_[0]->{value}" },
+    q{0+} => sub { $_[0]->{value} },
+    q{~}  => sub { ~( $_[0]->{value} ) },
+    # Binary
+    ( map { $_ => eval "sub { return \$_[0]->{value} $_ \$_[1] }" } qw( + * ) ), ## no critic
+    (
+        map {
+            $_ => eval ## no critic
+              "sub { return \$_[2] ? \$_[1] $_ \$_[0]->{value} : \$_[0]->{value} $_ \$_[1] }"
+        } qw( - / % ** << >> x <=> cmp & | ^ )
+    ),
+    (
+        map { $_ => eval "sub { return $_(\$_[0]->{value}) }" } ## no critic
+          qw( cos sin exp log sqrt int )
+    ),
+    q{atan2} => sub {
+        return $_[2] ? atan2( $_[1], $_[0]->{value} ) : atan2( $_[0]->{value}, $_[1] );
+    },
+
+    # Special
     fallback => 1,
 );
 
@@ -112,7 +131,7 @@ BSON::Int64 - BSON type wrapper for Int64
 
 =head1 VERSION
 
-version v0.999.1
+version v0.999.2
 
 =head1 SYNOPSIS
 
@@ -155,8 +174,9 @@ format, which represents it as a document as follows:
 
 =head1 OVERLOADING
 
-The numification operator (C<0+>) is overloaded to return the C<value>
-and fallback overloading is enabled.
+The numification operator, C<0+> is overloaded to return the C<value>,
+the full "minimal set" of overloaded operations is provided (per L<overload>
+documentation) and fallback overloading is enabled.
 
 =head1 AUTHORS
 
