@@ -6,7 +6,7 @@ package BSON::String;
 # ABSTRACT: BSON type wrapper for strings
 
 use version;
-our $VERSION = 'v0.999.1'; # TRIAL
+our $VERSION = 'v0.999.2'; # TRIAL
 
 use Moo;
 
@@ -57,7 +57,27 @@ sub BUILDARGS {
 sub TO_JSON { return "$_[0]->{value}" }
 
 use overload (
-    q{""}    => sub { $_[0]->{value} },
+    # Unary
+    q{""} => sub { $_[0]->{value} },
+    q{0+} => sub { 0+ $_[0]->{value} },
+    q{~}  => sub { ~( $_[0]->{value} ) },
+    # Binary
+    ( map { $_ => eval "sub { return \$_[0]->{value} $_ \$_[1] }" } qw( + * ) ), ## no critic
+    (
+        map {
+            $_ => eval ## no critic
+              "sub { return \$_[2] ? \$_[1] $_ \$_[0]->{value} : \$_[0]->{value} $_ \$_[1] }"
+        } qw( - / % ** << >> x <=> cmp & | ^ )
+    ),
+    (
+        map { $_ => eval "sub { return $_(\$_[0]->{value}) }" } ## no critic
+          qw( cos sin exp log sqrt int )
+    ),
+    q{atan2} => sub {
+        return $_[2] ? atan2( $_[1], $_[0]->{value} ) : atan2( $_[0]->{value}, $_[1] );
+    },
+
+    # Special
     fallback => 1,
 );
 
@@ -73,7 +93,7 @@ BSON::String - BSON type wrapper for strings
 
 =head1 VERSION
 
-version v0.999.1
+version v0.999.2
 
 =head1 SYNOPSIS
 
@@ -105,8 +125,9 @@ Returns value as a string.
 
 =head1 OVERLOADING
 
-The stringification operator (C<"">) is overloaded to return the C<value>
-and fallback overloading is enabled.
+The stringification operator (C<"">) is overloaded to return the C<value>,
+the full "minimal set" of overloaded operations is provided (per L<overload>
+documentation) and fallback overloading is enabled.
 
 =head1 AUTHORS
 
